@@ -340,9 +340,7 @@ def update(
         input_data.pop("_deploy", None)
         to_update = exclude_keys(deploy["exclude"], input_data or {})
 
-    merge(
-        final, existing_task, to_update or input_data, strategy=Strategy.TYPESAFE_REPLACE
-    )
+    merge(final, existing_task, to_update or input_data)
 
     # Exclude system fields must happen at the end otherwise
     # excluded fields specified in parameters might be deleted from the existing task
